@@ -8,7 +8,7 @@ class DingDingOptionsForm(forms.Form):
     )
     customer_markdown = forms.CharField(
         widget=forms.Textarea(attrs={u"rows": 5, u"class": u"span9"}),
-        initial=defaultMarkdown
+        initial=defaultMarkdown,
         help_text=u'''自定义markdown格式，\n支持变量：\n{var}'''.format(var='\n'.join(markdownMap.keys())),
         label=u"自定义内容",
         required=False,
