@@ -55,12 +55,15 @@ class DingDingPlugin(NotificationPlugin):
         send_url = DingTalk_API.format(token=access_token)
 
         customer_markdown = self.get_option('customer_markdown', group.project)
-        if customer_markdown is None or len(customer_markdown.strip()) <= 0:
-            customer_markdown = defaultMarkdown
-        linkUrl = u"{}events/{}/".format(group.get_absolute_url(), event.event_id)
-        detail.PROJECT_NAME = event.project.slug
-        detail.URL = linkUrl
-        text = formatTemplate(detail, customer_markdown)
+        try:
+            if customer_markdown is None or len(customer_markdown.strip()) <= 0:
+                customer_markdown = defaultMarkdown
+            linkUrl = u"{}events/{}/".format(group.get_absolute_url(), event.event_id)
+            detail.PROJECT_NAME = event.project.slug
+            detail.URL = linkUrl
+            text = formatTemplate(detail, customer_markdown)
+        except Exception as e:
+            text = ''' unknow error :  ''' + str(e)
         # print('TEMPLATE =======================>', text)
         data = {
             "msgtype": "markdown",
