@@ -30,7 +30,7 @@ def formatTemplate(detail, template=defaultMarkdown):
 		PROJECT_NAME=detail.PROJECT_NAME,
 		TITLE=detail.get('title'),
 		MESSAGE=detail.get('message').get('formatted'),
-		URL=detail.URL,
+		URL=detail.get('URL'),
 		ENV=detail.get('environment'),
 		PLATFORM=detail.get('platform'),
 		DATETIME=detail.get('datetime'),
